==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataSourceSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSupportingCalculationDescription } from "./DataSourceSupportingCalculationDescription";
/**
 * @hidden
 */
var DataSourceSupportingCalculationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceSupportingCalculationDescriptionMetadata, _super);
    function DataSourceSupportingCalculationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSupportingCalculationDescriptionMetadata.b = function (a) {
        if (DataSourceSupportingCalculationDescriptionMetadata.a == null) {
            DataSourceSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSupportingCalculationDescriptionMetadata.c(DataSourceSupportingCalculationDescriptionMetadata.a);
        }
        if (a.g(DataSourceSupportingCalculationDescriptionMetadata.a)) {
            return;
        }
        a.s(DataSourceSupportingCalculationDescriptionMetadata.a);
    };
    DataSourceSupportingCalculationDescriptionMetadata.c = function (a) {
    };
    DataSourceSupportingCalculationDescriptionMetadata.d = function (a) {
        DataSourceSupportingCalculationDescriptionMetadata.b(a);
        a.u("DataSourceSupportingCalculation", function () { return new DataSourceSupportingCalculationDescription(); });
        a.t("DataSourceSupportingCalculation", DataSourceSupportingCalculationDescriptionMetadata.a);
    };
    DataSourceSupportingCalculationDescriptionMetadata.$t = markType(DataSourceSupportingCalculationDescriptionMetadata, 'DataSourceSupportingCalculationDescriptionMetadata');
    DataSourceSupportingCalculationDescriptionMetadata.a = null;
    return DataSourceSupportingCalculationDescriptionMetadata;
}(Base));
export { DataSourceSupportingCalculationDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataSourceSupportingCalculationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataSourceSupportingCalculationDescription } from "./DataSourceSupportingCalculationDescription";
/**
 * @hidden
 */
var DataSourceSupportingCalculationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataSourceSupportingCalculationDescriptionMetadata, _super);
    function DataSourceSupportingCalculationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataSourceSupportingCalculationDescriptionMetadata.b = function (a) {
        if (DataSourceSupportingCalculationDescriptionMetadata.a == null) {
            DataSourceSupportingCalculationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataSourceSupportingCalculationDescriptionMetadata.c(DataSourceSupportingCalculationDescriptionMetadata.a);
        }
        if (a.j(DataSourceSupportingCalculationDescriptionMetadata.a)) {
            return;
        }
        a.y(DataSourceSupportingCalculationDescriptionMetadata.a);
    };
    DataSourceSupportingCalculationDescriptionMetadata.c = function (a) {
    };
    DataSourceSupportingCalculationDescriptionMetadata.d = function (a) {
        DataSourceSupportingCalculationDescriptionMetadata.b(a);
        a.aa("DataSourceSupportingCalculation", function () { return new DataSourceSupportingCalculationDescription(); });
        a.z("DataSourceSupportingCalculation", DataSourceSupportingCalculationDescriptionMetadata.a);
    };
    DataSourceSupportingCalculationDescriptionMetadata.$t = markType(DataSourceSupportingCalculationDescriptionMetadata, 'DataSourceSupportingCalculationDescriptionMetadata');
    DataSourceSupportingCalculationDescriptionMetadata.a = null;
    return DataSourceSupportingCalculationDescriptionMetadata;
}(Base));
export { DataSourceSupportingCalculationDescriptionMetadata };
